/* ********************************************************/
/* ********************************************************/
/* *                                                    * */
/* *               BANG COMMAND SECTION                 * */
/* *                                                    * */
/* ********************************************************/
/* ********************************************************/

#define BANG_HIDE          TEXT("!grdTrayHide")
#define BANG_SHOW          TEXT("!grdTrayShow")
#define BANG_TOGGLE        TEXT("!grdTrayToggle")
#define BANG_MOVE          TEXT("!grdTrayMove")

grdBangs::grdBangs( HWND hTray, grdSysTraySettings *cfg ) {

	this->hSysTray = hTray;
	this->settings = cfg;

	AddBangCommand( "!grdTrayHide",   this->grdTrayHide   );
	AddBangCommand( "!grdTrayShow",   this->grdTrayShow   );
	AddBangCommand( "!grdTrayToggle", this->grdTrayToggle );
	AddBangCommand( "!grdTrayMove",   this->grdTrayMove   );

}

grdBangs::~grdBangs() {

	RemoveBangCommand( "!grdTrayHide"   );
	RemoveBangCommand( "!grdTrayShow"   );
	RemoveBangCommand( "!grdTrayToggle" );
	RemoveBangCommand( "!grdTrayMove"   );


}



/***********************************************************
* void SystrayHide()                                       *
*                         *  *  *  *                       *
*    Arguments:                                            *
*                                                          *
*    - HWND hCaller                                        *
*      The HWND of the window that called this !Bang       *
*    - LPCTSTR pszArgs                                     *
*      Should be the arguments to the function...          *
*                         *  *  *  *                       *
* Handles the !Bang to hide the System Tray                *
***********************************************************/
void grdBangs::SystrayHide( HWND hCaller, LPCTSTR pszArgs ) {

	ShowWindow( this->hSysTray, SW_HIDE );

}

/***********************************************************
* void SystrayShow()                                       *
*                         *  *  *  *                       *
*    Arguments:                                            *
*                                                          *
*    - HWND hCaller                                        *
*      The HWND of the window that called this !Bang       *
*    - LPCTSTR pszArgs                                     *
*      Should be the arguments to the function...          *
*                         *  *  *  *                       *
* Handles the !Bang to show the System Tray                *
***********************************************************/
void grdBangs::SystrayShow( HWND hCaller, LPCTSTR pszArgs ) {

	ShowWindow( this->hSysTray, SW_SHOWNOACTIVATE );

}

/***********************************************************
* void SystrayToggle()                                     *
*                         *  *  *  *                       *
*    Arguments:                                            *
*                                                          *
*    - HWND hCaller                                        *
*      The HWND of the window that called this !Bang       *
*    - LPCTSTR pszArgs                                     *
*      Should be the arguments to the function...          *
*                         *  *  *  *                       *
* Handles the !Bang to toggle the System Tray visibilty    *
***********************************************************/
void grdBangs::SystrayToggle( HWND hCaller, LPCTSTR pszArgs ) {

	BOOL visible = IsWindowVisible( this->hSysTray );
    ShowWindow( this->hSysTray, ( (visible) ? SW_SHOWNOACTIVATE : SW_HIDE) );

}

/***********************************************************
* void SystrayMove()                                       *
*                         *  *  *  *                       *
*    Arguments:                                            *
*                                                          *
*    - HWND hCaller                                        *
*      The HWND of the window that called this !Bang       *
*    - LPCTSTR pszArgs                                     *
*      Should be the arguments to the function...          *
*                         *  *  *  *                       *
* Handles the !Bang to move the System Tray                *
***********************************************************/

void grdBangs::SystrayMove( HWND hCaller, LPCTSTR pszArgs ) {

	LPCTSTR p = pszArgs;
	TCHAR szValue[16];
	
	p = NextToken( p, szValue, 16 );
	nX = ParseInteger( szValue );
	nX = (nX < 0) ? (nScreenX + nX + 1) : nX;
	
	p = NextToken( p, szValue, 16 );
	nY = ParseInteger( szValue );
	nY = (nY < 0) ? (nScreenY + nY + 1) : nY;
	
	SetWindowPos( this->hSysTray, NULL, nX, nY, 0, 0, SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE );

}
